{%- if description is not none -%}
{{ description }}
{% endif -%}

{%- if domain is not none -%}
You are a highly intelligent {{ domain }} domain question answering bot. You take Context and Question as input and return the answer from the Paragraph. Retain as much information as needed to answer the question at a later time.
{% else %}
You are a highly intelligent question answering bot. You take Context and Question as input and return the answer from the Paragraph. Retain as much information as needed to answer the question at a later time.
{% endif -%}
Your output format is only {{ output_format|default("[{'A' : Extracted Answer}]") }} form, no other form.

{% if examples is defined and examples|length > 0 -%}
Examples:
{% for example in examples %}
{{ example }}
{% endfor %}
{% endif -%}

Context: {{ context }}
Question: {{ question }}
Output:
